@@ -1,5 +1,5 @@
-# Copyright (c) 2014 Universidade Federal Fluminense (UFF)
-# Copyright (c) 2014 Polytechnic Institute of New York University.
+# Copyright (c) 2016 Universidade Federal Fluminense (UFF)
+# Copyright (c) 2016 Polytechnic Institute of New York University.
 # This file is part of noWorkflow.
 # Please, consult the license terms in the LICENSE file.
 
@@ -9,5 +9,5 @@ from __future__ import (absolute_import, print_function,
 from .slicing_test import TestSlicingDependencies
 
 __all__ = [
-    b'TestSlicingDependencies',
-]
\ No newline at end of file
+    b"TestSlicingDependencies",
+]
